@@ -1,11 +1,11 @@
 use crate::node::Text;
-use crate::PatchPath;
+use crate::TreePath;
 
 /// The patch is changing the text content of a text node
 #[derive(Clone, Debug, PartialEq)]
 pub struct ChangeText<'a> {
     /// the target element to be patch can be traverse using this patch path
-    pub patch_path: PatchPath,
+    pub patch_path: TreePath,
     /// the old text is not really needed for applying the patch.
     /// but it is useful for debugging purposed, that we are changing the intended target text by
     /// visual inspection
@@ -16,7 +16,7 @@ pub struct ChangeText<'a> {
 
 impl<'a> ChangeText<'a> {
     /// create a new change text patch
-    pub fn new(old: &'a Text, patch_path: PatchPath, new: &'a Text) -> Self {
+    pub fn new(old: &'a Text, patch_path: TreePath, new: &'a Text) -> Self {
         ChangeText {
             patch_path,
             old,
