@@ -1,4 +1,4 @@
-use crate::PatchPath;
+use crate::TreePath;
 use std::fmt::Debug;
 
 /// remove the node at this
@@ -10,14 +10,14 @@ where
     /// the tag of the node that is to be removed
     pub tag: Option<&'a TAG>,
     /// the node_idx of the node to be removed
-    pub patch_path: PatchPath,
+    pub patch_path: TreePath,
 }
 impl<'a, TAG> RemoveNode<'a, TAG>
 where
     TAG: PartialEq + Clone + Debug,
 {
     /// create a new RemoveNode patch
-    pub fn new(tag: Option<&'a TAG>, patch_path: PatchPath) -> Self {
+    pub fn new(tag: Option<&'a TAG>, patch_path: TreePath) -> Self {
         RemoveNode { tag, patch_path }
     }
 }
