@@ -1,5 +1,4 @@
 use crate::Node;
-use crate::NodeIdx;
 use std::fmt::Debug;
 
 /// Describe the path traversal of a Node starting from the root node
@@ -74,20 +73,6 @@ pub struct TreePath {
     pub path: Vec<usize>,
 }
 
-/// This contains the information on how to traverse the node from the root
-/// to get to the target element of this patch.
-///
-/// Note: The logic to apply the patch, must get a reference to the target elements first
-/// before applying any of the patches. Doing so will prevent us from targeting the wrong nodem
-/// once a partial patch is applied to some other elements.
-#[derive(Debug, Clone, PartialEq)]
-pub struct PatchPath {
-    /// The target path traversal of this patch
-    pub old_path: TreePath,
-    /// The new patch traversal after this patch has been applied
-    pub new_path: Option<TreePath>,
-}
-
 impl TreePath {
     /// create a tree path which starts at `node_idx` 0 and traversal path `path` at `vec![0]`.
     pub fn new() -> Self {
@@ -107,74 +92,43 @@ impl TreePath {
     }
 
     /// find the node using the path of this tree path
-    pub fn find_node_by_path<'a, NS, TAG, ATT, VAL, EVENT>(
+    pub fn find_node_by_path<'a, NS, TAG, ATT, VAL>(
         &self,
-        node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
-    ) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+        node: &'a Node<NS, TAG, ATT, VAL>,
+    ) -> Option<&'a Node<NS, TAG, ATT, VAL>>
     where
         NS: PartialEq + Clone + Debug,
         TAG: PartialEq + Clone + Debug,
         ATT: PartialEq + Clone + Debug,
         VAL: PartialEq + Clone + Debug,
-        EVENT: PartialEq + Clone + Debug,
     {
         find_node_by_path(node, &self)
     }
 
     /// find the node using the node_idx of this tree path
-    pub fn find_node_by_node_idx<'a, NS, TAG, ATT, VAL, EVENT>(
+    pub fn find_node_by_node_idx<'a, NS, TAG, ATT, VAL>(
         &self,
-        node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
-    ) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+        node: &'a Node<NS, TAG, ATT, VAL>,
+    ) -> Option<&'a Node<NS, TAG, ATT, VAL>>
     where
         NS: PartialEq + Clone + Debug,
         TAG: PartialEq + Clone + Debug,
         ATT: PartialEq + Clone + Debug,
         VAL: PartialEq + Clone + Debug,
-        EVENT: PartialEq + Clone + Debug,
     {
         find_node_by_node_idx(node, &self)
     }
 }
 
-impl PatchPath {
-    /// create a PatchPath with old_path and new_path specified
-    pub fn new(old_path: TreePath, new_path: TreePath) -> Self {
-        Self {
-            old_path,
-            new_path: Some(new_path),
-        }
-    }
-
-    /// PatchPath that doesn't need to have new patch such as RemoveNode
-    pub fn old(old_path: TreePath) -> Self {
-        Self {
-            old_path,
-            new_path: None,
-        }
-    }
-
-    /// return the node id of this PatchPath
-    pub fn node_idx(&self) -> NodeIdx {
-        self.old_path.node_idx
-    }
-
-    /// return the traversal path of this PatchPath
-    pub fn traversal_path(&self) -> &[usize] {
-        &self.old_path.path
-    }
-}
-
-fn traverse_node_by_path<'a, NS, TAG, ATT, VAL, EVENT>(
-    node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
+fn traverse_node_by_path<'a, NS, TAG, ATT, VAL>(
+    node: &'a Node<NS, TAG, ATT, VAL>,
     path: &mut TreePath,
-) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+) -> Option<&'a Node<NS, TAG, ATT, VAL>>
 where
     NS: PartialEq + Clone + Debug,
     TAG: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
-    EVENT: PartialEq + Clone + Debug,
 {
     println!("\n Traversing path: {:?}", path);
     if path.path.is_empty() {
@@ -192,17 +146,16 @@ where
     }
 }
 
-fn traverse_node_by_node_idx<'a, NS, TAG, ATT, VAL, EVENT>(
-    node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
+fn traverse_node_by_node_idx<'a, NS, TAG, ATT, VAL>(
+    node: &'a Node<NS, TAG, ATT, VAL>,
     path: &TreePath,
     cur_node_idx: &mut usize,
-) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+) -> Option<&'a Node<NS, TAG, ATT, VAL>>
 where
     NS: PartialEq + Clone + Debug,
     TAG: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
-    EVENT: PartialEq + Clone + Debug,
 {
     println!("\nTraversing path: {:?}", path);
     println!("\tcur_node_idx: {}", cur_node_idx);
@@ -225,16 +178,15 @@ where
     }
 }
 
-fn find_node_by_path<'a, NS, TAG, ATT, VAL, EVENT>(
-    node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
+fn find_node_by_path<'a, NS, TAG, ATT, VAL>(
+    node: &'a Node<NS, TAG, ATT, VAL>,
     path: &TreePath,
-) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+) -> Option<&'a Node<NS, TAG, ATT, VAL>>
 where
     NS: PartialEq + Clone + Debug,
     TAG: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
-    EVENT: PartialEq + Clone + Debug,
 {
     let mut path = path.clone();
     let root_idx = path.path.remove(0); // remove the first 0
@@ -242,16 +194,15 @@ where
     traverse_node_by_path(node, &mut path)
 }
 
-fn find_node_by_node_idx<'a, NS, TAG, ATT, VAL, EVENT>(
-    node: &'a Node<NS, TAG, ATT, VAL, EVENT>,
+fn find_node_by_node_idx<'a, NS, TAG, ATT, VAL>(
+    node: &'a Node<NS, TAG, ATT, VAL>,
     path: &TreePath,
-) -> Option<&'a Node<NS, TAG, ATT, VAL, EVENT>>
+) -> Option<&'a Node<NS, TAG, ATT, VAL>>
 where
     NS: PartialEq + Clone + Debug,
     TAG: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
-    EVENT: PartialEq + Clone + Debug,
 {
     traverse_node_by_node_idx(node, &path, &mut 0)
 }
@@ -261,8 +212,7 @@ mod tests {
     use super::*;
     use crate::*;
 
-    type MyNode =
-        Node<&'static str, &'static str, &'static str, &'static str, ()>;
+    type MyNode = Node<&'static str, &'static str, &'static str, &'static str>;
 
     fn sample_node() -> MyNode {
         let node: MyNode = element(
